@@ -1,5 +1,9 @@
 from django.apps import AppConfig
-from django.utils.translation import ugettext_lazy as _
+
+try:
+    from django.utils.translation import ugettext_lazy as _
+except ImportError:
+    from django.utils.translation import gettext_lazy as _
 
 
 class Config(AppConfig):
@@ -7,7 +11,7 @@ class Config(AppConfig):
     Config for django_inline_sass application.
     """
     name = 'django_inline_sass'
-    label = 'django-inline-sass'
+    label = 'django_inline_sass'
     verbose_name = _('Django Inline SASS')
 
     def ready(self):
